# Changelog
### v1.1.2
Release date: 2025-04-17
- Pass argv to RetroShine

### v1.1.1
Release date: 2025-04-17
- Support RetroShine fast preview with loaded_model

### v1.1.0
Release date: 2025-04-16
- 16/48-bit support for PNG, TIFF
- Support ICC-profiles
- Callback and improved support for RetroShine

### v1.0.1
Released date: 2015-04-16
- github workflow
- test against PIL 11

### v1.0.0
Release date: 2024-11-08
- Simplified CLI options
- Python f-string options
- Semantic Versioning
- Tests and pyproject.toml

### v0.2.0
Release date: 2024-09-03
- Support Free Curve Inference models

### v0.1.0
Release date: 2024-01-21
- JPEG: Preserve EXIF and quality
- Add Versioning
- Add Changelog
- Dump version/parameters in comment/EXIF
